# ReplaceSupport 1.0.3
# (c) 2000-2005, Stefan H. Holek, stefan@epy.co.at
# http://zope.org/Members/shh/ReplaceSupport
# License: ZPL
# Zope: 2.6-2.8

__doc__ = 'Add a Replace tab to Folders'
__version__ = '1.0.3'

__refresh_module__ = 0

try:

    from Globals import default__class_init__
    from OFS.FindSupport import FindSupport
    from ReplaceSupport import ReplaceSupport

    FindSupport.__ac_permissions__ = FindSupport.__ac_permissions__ + ReplaceSupport.__ac_permissions__
    FindSupport.manage_options = FindSupport.manage_options + ReplaceSupport.manage_options
    FindSupport.manage_replaceForm = ReplaceSupport.manage_replaceForm
    FindSupport.manage_replaceResult = ReplaceSupport.manage_replaceResult 
    FindSupport.ZopeReplace = ReplaceSupport.ZopeReplace.im_func
    FindSupport.PrincipiaReplace = ReplaceSupport.ZopeReplace.im_func
    FindSupport._ZopeReplace = ReplaceSupport._ZopeReplace.im_func
    FindSupport._PrincipiaReplace = ReplaceSupport._ZopeReplace.im_func
    FindSupport._ReplaceHandlerRegistry = ReplaceSupport._ReplaceHandlerRegistry
    FindSupport.getReplaceHandlerMetaTypes = ReplaceSupport.getReplaceHandlerMetaTypes.im_func

    default__class_init__(FindSupport)

    from zLOG import LOG, INFO
    LOG('ReplaceSupport', INFO, 'Applied patch version %s.' % __version__)
  
except:

    import traceback
    traceback.print_exc()

